@@ -97,7 +97,7 @@ __filter_readonly_variables() {
 	# Untrusted due to possible application of package renames to binpkgs
 	local binpkg_untrusted_vars="CATEGORY P PF PN PR PV PVR"
 	local misc_garbage_vars="_portage_filter_opts"
-	filtered_vars="$readonly_bash_vars $bash_misc_vars
+	filtered_vars="___.* $readonly_bash_vars $bash_misc_vars
 		$PORTAGE_READONLY_VARS $misc_garbage_vars"
 
 	# Filter SYSROOT unconditionally. It is propagated in every EAPI
@@ -981,9 +981,8 @@ __ebuild_main() {
 	# respect FEATURES="-ccache".
 	has ccache $FEATURES || export CCACHE_DISABLE=1
 
-	local phase_func=$(__ebuild_arg_to_phase "$EBUILD_PHASE")
-	[[ -n $phase_func ]] && __ebuild_phase_funcs "$EAPI" "$phase_func"
-	unset phase_func
+	local ___phase_func=$(__ebuild_arg_to_phase "$EBUILD_PHASE")
+	[[ -n ${___phase_func} ]] && __ebuild_phase_funcs "$EAPI" "${___phase_func}"
 
 	__source_all_bashrcs
 
