@@ -157,7 +157,8 @@ class config(object):
 		'PORTAGE_PYM_PATH', 'PORTAGE_PYTHONPATH'])
 
 	_deprecated_keys = {'PORTAGE_LOGDIR': 'PORT_LOGDIR',
-		'PORTAGE_LOGDIR_CLEAN': 'PORT_LOGDIR_CLEAN'}
+		'PORTAGE_LOGDIR_CLEAN': 'PORT_LOGDIR_CLEAN',
+		'SIGNED_OFF_BY': 'DCO_SIGNED_OFF_BY'}
 
 	_setcpv_aux_keys = ('BDEPEND', 'DEFINED_PHASES', 'DEPEND', 'EAPI', 'HDEPEND',
 		'INHERITED', 'IUSE', 'REQUIRED_USE', 'KEYWORDS', 'LICENSE', 'PDEPEND',
